pub struct ActionProposal {
pub id: String,
pub source: String,
pub actions: Vec<Action>,
pub timestamp: DateTime<Utc>,
pub context: HashMap<String, Value>,
}Expand description
A batch of actions proposed by a model for runtime validation and execution.
Fields
id: Stringsource: Stringactions: Vec<Action>timestamp: DateTime<Utc>context: HashMap<String, Value>Trait Implementations
Sourceimpl Clone for ActionProposal
impl Clone for ActionProposal
Sourcefn clone(&self) -> ActionProposal
fn clone(&self) -> ActionProposal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionProposal
impl Debug for ActionProposal
Sourceimpl<'de> Deserialize<'de> for ActionProposal
impl<'de> Deserialize<'de> for ActionProposal
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ActionProposal, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ActionProposal, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ActionProposal
impl PartialEq for ActionProposal
Sourcefn eq(&self, other: &ActionProposal) -> bool
fn eq(&self, other: &ActionProposal) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ActionProposal
impl Serialize for ActionProposal
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ActionProposal