pub struct SubprocessToolExecutor { /* private fields */ }Expand description
Tool executor that runs tools as subprocesses via stdin/stdout JSON-RPC.
Implementations
Sourceimpl SubprocessToolExecutor
impl SubprocessToolExecutor
pub fn new() -> Self
Sourcepub fn register(&mut self, name: &str, tool: SubprocessTool)
pub fn register(&mut self, name: &str, tool: SubprocessTool)
Register a subprocess tool.
Sourcepub fn with_fallback(self, fallback: Arc<dyn ToolExecutor>) -> Self
pub fn with_fallback(self, fallback: Arc<dyn ToolExecutor>) -> Self
Set a fallback executor for tools not registered as subprocesses.